@@ -1,6 +1,7 @@
 use crate::algorithms::ptd::{PostType, Type};
 use crate::indieauth::AccessToken;
 use serde::{Deserialize, Serialize};
+use std::convert::Infallible;
 use std::str::FromStr;
 use std::string::ToString;
 
@@ -73,6 +74,17 @@ pub struct Channel {
     pub name: String,
 }
 
+impl FromStr for Channel {
+    type Err = Infallible;
+
+    fn from_str(s: &str) -> Result<Self, Self::Err> {
+        Ok(Self {
+            uid: s.to_string(),
+            name: s.to_string(),
+        })
+    }
+}
+
 /// Represents the normalized form of pagination in Micropub queries.
 #[derive(Deserialize, Serialize, Clone, Debug, PartialEq, Default)]
 #[serde(rename_all = "kebab-case")]
@@ -442,7 +454,10 @@ mod tests {
             .unwrap(),
             QueryResponse::Configuration {
                 q: vec!["source".to_string(), "post-types".to_string()],
-                channels: vec!["pages".to_string(), "posts".to_string()],
+                channels: vec![
+                    Channel::from_str("pages").unwrap(),
+                    Channel::from_str("posts").unwrap()
+                ],
                 media_endpoint: "http://micropub.endpoint".parse().ok(),
                 post_types: vec![
                     PostType::Simple(Type::Note),
