@@ -28,7 +28,7 @@ where
         .request(reqwest::Method::POST, req.endpoint.clone())
         .header("accept", "text/html,application/json")
         .header("content-type", "application/x-www-form-urlencoded")
-        .body(serde_urlencoded::to_string(&req).map_err(|e| Error::Other(e.into()))?)
+        .body(serde_qs::to_string(&req).map_err(|e| Error::Other(e.into()))?)
         .send()
         .await
         .map_err(|err| Error::Other(err.into()))?;
@@ -75,7 +75,7 @@ pub async fn dispatch<C>(
     cfg: &C,
     source_url: &str,
     target_url: &str,
-    options: Option<Request>,
+    additional_options: Option<Request>,
 ) -> Result<Vec<Response>, Error>
 where
     C: IConfiguration + Sync + Send + Sized,
@@ -84,12 +84,13 @@ where
     let endpoints = endpoints_for(cfg, target_url).await?;
     let mut responses = vec![];
 
-    for endpoint in endpoints.iter() {
+    for endpoint in endpoints.into_iter() {
+        let options = additional_options.clone().unwrap_or_default();
         let req = Request {
-            endpoint: endpoint.clone(),
+            endpoint,
             source: source_url.to_owned(),
             target: target_url.to_owned(),
-            ..options.clone().unwrap_or_default()
+            ..options
         };
 
         responses.push(send(cfg, &req).await?);
